#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	/// <summary>
    /// Calculate Momentum in Deviations from recent swing highs and lows to normalize price movement
	/// 
	/// Code Written by Tyler Moore
	/// www.FreeIndicators.Com
	/// 
	/// For modifications to this code or to have your own custom code written
	/// please visit www.MooreTechLLC.com	
    /// </summary>
	public class mtSwingMomentum : Indicator
	{
		private mtSwingOscillator so;
		
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Calculate Momentum in Deviations from recent swing highs and lows to normalize price movement from www.FreeIndicators.com";
				Name										= "mtSwingMomentum";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= true;
				DrawVerticalGridLines						= true;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				Strength					= 10;
				MomentumLength					= 5;
				AddPlot(new Stroke(Brushes.Blue, 1),PlotStyle.Bar,"Velocity");
			}
			else if (State == State.Configure)
			{
			}
			else if (State == State.DataLoaded)
			{
				so=mtSwingOscillator(Strength);
			}
		}

		protected override void OnBarUpdate()
		{
			if (CurrentBar<MomentumLength)
				return;
			
            Velocity[0] = (so[0]-so[MomentumLength]);
		}

		#region Properties
		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="Strength", Order=1, GroupName="Parameters")]
		public int Strength
		{ get; set; }

		[NinjaScriptProperty]
		[Range(1, int.MaxValue)]
		[Display(Name="MomentumLength", Order=2, GroupName="Parameters")]
		public int MomentumLength
		{ get; set; }

		[Browsable(false)]
		[XmlIgnore]
		public Series<double> Velocity
		{
			get { return Values[0]; }
		}
		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private mtSwingMomentum[] cachemtSwingMomentum;
		public mtSwingMomentum mtSwingMomentum(int strength, int momentumLength)
		{
			return mtSwingMomentum(Input, strength, momentumLength);
		}

		public mtSwingMomentum mtSwingMomentum(ISeries<double> input, int strength, int momentumLength)
		{
			if (cachemtSwingMomentum != null)
				for (int idx = 0; idx < cachemtSwingMomentum.Length; idx++)
					if (cachemtSwingMomentum[idx] != null && cachemtSwingMomentum[idx].Strength == strength && cachemtSwingMomentum[idx].MomentumLength == momentumLength && cachemtSwingMomentum[idx].EqualsInput(input))
						return cachemtSwingMomentum[idx];
			return CacheIndicator<mtSwingMomentum>(new mtSwingMomentum(){ Strength = strength, MomentumLength = momentumLength }, input, ref cachemtSwingMomentum);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.mtSwingMomentum mtSwingMomentum(int strength, int momentumLength)
		{
			return indicator.mtSwingMomentum(Input, strength, momentumLength);
		}

		public Indicators.mtSwingMomentum mtSwingMomentum(ISeries<double> input , int strength, int momentumLength)
		{
			return indicator.mtSwingMomentum(input, strength, momentumLength);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.mtSwingMomentum mtSwingMomentum(int strength, int momentumLength)
		{
			return indicator.mtSwingMomentum(Input, strength, momentumLength);
		}

		public Indicators.mtSwingMomentum mtSwingMomentum(ISeries<double> input , int strength, int momentumLength)
		{
			return indicator.mtSwingMomentum(input, strength, momentumLength);
		}
	}
}

#endregion
